@@ -25,83 +25,82 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import orca.focus_manager as focus_manager
-import orca.scripts.toolkits.gtk as gtk
+from orca import focus_manager
+from orca import input_event_manager
+from orca.scripts.toolkits import gtk
 from orca.ax_object import AXObject
+from orca.ax_text import AXText
 from orca.ax_utilities import AXUtilities
 from .spellcheck import SpellCheck
 
 
 class Script(gtk.Script):
 
-    def __init__(self, app):
-        """Creates a new script for the given application."""
-
-        gtk.Script.__init__(self, app)
-
-    def getSpellCheck(self):
+    def get_spellcheck(self):
         """Returns the spellcheck for this script."""
 
         return SpellCheck(self)
 
-    def getAppPreferencesGUI(self):
+    def get_app_preferences_gui(self):
         """Returns a GtkGrid containing the application unique configuration
         GUI items for the current application."""
 
+        import gi
+        gi.require_version("Gtk", "3.0")
         from gi.repository import Gtk
 
         grid = Gtk.Grid()
         grid.set_border_width(12)
-        grid.attach(self.spellcheck.getAppPreferencesGUI(), 0, 0, 1, 1)
+        grid.attach(self.spellcheck.get_app_preferences_gui(), 0, 0, 1, 1)
         grid.show_all()
 
         return grid
 
-    def getPreferencesFromGUI(self):
+    def get_preferences_from_gui(self):
         """Returns a dictionary with the app-specific preferences."""
 
-        return self.spellcheck.getPreferencesFromGUI()
+        return self.spellcheck.get_preferences_from_gui()
 
-    def locusOfFocusChanged(self, event, oldFocus, newFocus):
+    def locus_of_focus_changed(self, event, old_focus, new_focus):
         """Handles changes of focus of interest to the script."""
 
-        if self.spellcheck.isSuggestionsItem(newFocus):
-            includeLabel = not self.spellcheck.isSuggestionsItem(oldFocus)
-            self.updateBraille(newFocus)
+        if self.spellcheck.isSuggestionsItem(new_focus):
+            includeLabel = not self.spellcheck.isSuggestionsItem(old_focus)
+            self.update_braille(new_focus)
             self.spellcheck.presentSuggestionListItem(includeLabel=includeLabel)
             return
 
-        super().locusOfFocusChanged(event, oldFocus, newFocus)
+        super().locus_of_focus_changed(event, old_focus, new_focus)
 
-    def onActiveDescendantChanged(self, event):
+    def on_active_descendant_changed(self, event):
         """Callback for object:active-descendant-changed accessibility events."""
 
         if event.source == self.spellcheck.getSuggestionsList():
             return
 
-        gtk.Script.onActiveDescendantChanged(self, event)
+        gtk.Script.on_active_descendant_changed(self, event)
 
-    def onCaretMoved(self, event):
+    def on_caret_moved(self, event):
         """Callback for object:text-caret-moved accessibility events."""
 
         if AXUtilities.is_multi_line(event.source):
             self.spellcheck.setDocumentPosition(event.source, event.detail1)
 
-        gtk.Script.onCaretMoved(self, event)
+        gtk.Script.on_caret_moved(self, event)
 
-    def onFocusedChanged(self, event):
+    def on_focused_changed(self, event):
         """Callback for object:state-changed:focused accessibility events."""
 
         if not event.detail1:
             return
 
-        gtk.Script.onFocusedChanged(self, event)
+        gtk.Script.on_focused_changed(self, event)
 
-    def onNameChanged(self, event):
+    def on_name_changed(self, event):
         """Callback for object:property-change:accessible-name events."""
 
         if not self.spellcheck.isActive():
-            gtk.Script.onNameChanged(self, event)
+            gtk.Script.on_name_changed(self, event)
             return
 
         name = AXObject.get_name(event.source)
@@ -115,29 +114,29 @@ class Script(gtk.Script):
             return
 
         entry = self.spellcheck.getChangeToEntry()
-        if name != self.utilities.displayedText(entry):
+        if name != AXText.get_all_text(entry):
             return
 
         # If we're here, the locusOfFocus was in the selection list when
         # that list got destroyed and repopulated. Focus is still there.
-        focus_manager.getManager().set_locus_of_focus(event, event.source, False)
-        self.updateBraille(event.source)
+        focus_manager.get_manager().set_locus_of_focus(event, event.source, False)
+        self.update_braille(event.source)
 
-    def onSensitiveChanged(self, event):
+    def on_sensitive_changed(self, event):
         """Callback for object:state-changed:sensitive accessibility events."""
 
         if event.source == self.spellcheck.getChangeToEntry() \
            and self.spellcheck.presentCompletionMessage():
             return
 
-        gtk.Script.onSensitiveChanged(self, event)
+        gtk.Script.on_sensitive_changed(self, event)
 
-    def onTextSelectionChanged(self, event):
+    def on_text_selection_changed(self, event):
         """Callback for object:text-selection-changed accessibility events."""
 
-        focus = focus_manager.getManager().get_locus_of_focus()
+        focus = focus_manager.get_manager().get_locus_of_focus()
         if event.source == focus:
-            gtk.Script.onTextSelectionChanged(self, event)
+            gtk.Script.on_text_selection_changed(self, event)
             return
 
         if not self.utilities.isSearchEntry(focus, True):
@@ -147,26 +146,26 @@ class Script(gtk.Script):
             return
 
         # To avoid extreme chattiness.
-        keyString, mods = self.utilities.lastKeyAndModifiers()
-        if keyString in ["BackSpace", "Delete"]:
+        manager = input_event_manager.get_manager()
+        if manager.last_event_was_backspace() or manager.last_event_was_delete():
             return
 
         self.sayLine(event.source)
 
-    def onWindowActivated(self, event):
+    def on_window_activated(self, event):
         """Callback for window:activate accessibility events."""
 
-        gtk.Script.onWindowActivated(self, event)
+        gtk.Script.on_window_activated(self, event)
         if not self.spellcheck.isCheckWindow(event.source):
             return
 
         self.spellcheck.presentErrorDetails()
         entry = self.spellcheck.getChangeToEntry()
-        focus_manager.getManager().set_locus_of_focus(None, entry, False)
-        self.updateBraille(entry)
+        focus_manager.get_manager().set_locus_of_focus(None, entry, False)
+        self.update_braille(entry)
 
-    def onWindowDeactivated(self, event):
+    def on_window_deactivated(self, event):
         """Callback for window:deactivate accessibility events."""
 
-        gtk.Script.onWindowDeactivated(self, event)
+        gtk.Script.on_window_deactivated(self, event)
         self.spellcheck.deactivate()
